Summary: A library of functions for manipulating PNG image format files
Name: libpng
Version: 1.5.15
Release: 1
Epoch: 2
License: zlib
Group: System Environment/Libraries
URL: http://www.libpng.org/pub/png/
Source0: ftp://ftp.simplesystems.org/pub/png/src/%{name}-%{version}.tar.bz2
Source1: libpng.so.3-aix32
Source2: libpng.so.3-aix64
Source3: libpng12.a
Source4: libpng14.so.14-aix32
Source5: libpng14.so.14-aix64

Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: zlib-devel
Requires: zlib

%description
The libpng package contains a library of functions for creating and
manipulating PNG (Portable Network Graphics) image format files.  PNG
is a bit-mapped graphics format similar to the GIF format.  PNG was
created to replace the GIF format, since GIF uses a patented data
compression algorithm.

Libpng should be installed if you need to manipulate PNG format image
files.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Development tools for programs to manipulate PNG image format files
Group: Development/Libraries
Requires: %{name} = %{version}-%{release} zlib-devel pkg-config

%description devel
The libpng-devel package contains header files and documentation necessary
for developing programs using the PNG (Portable Network Graphics) library.

If you want to develop programs which will manipulate PNG image format
files, you should install libpng-devel.  You'll also need to install
the libpng package.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc -q64" or "gcc -maix64".


%prep
%setup -q


%build
export CONFIG_SHELL=/usr/bin/ksh
export CONFIG_ENV_ARGS=/usr/bin/ksh

# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
export CC="cc -q64"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static
make %{?_smp_mflags}

cp .libs/libpng15.so.15 .
make distclean

# now build the 32-bit version
export CC="cc"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
make DESTDIR=${RPM_BUILD_ROOT} install

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libpng15.a ./libpng15.so.15

# Add the older v1.2.xx shared members for compatibility with older apps
# (make sure they're set for LOADONLY with 'strip -e')
cp %{SOURCE1} libpng.so.3
/usr/bin/strip -X32 -e libpng.so.3
/usr/bin/ar -X32 -q ${RPM_BUILD_ROOT}%{_libdir}/libpng.a libpng.so.3

cp %{SOURCE2} libpng.so.3
/usr/bin/strip -X64 -e libpng.so.3
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libpng.a libpng.so.3

# copy the old libpng12.a library for compatibility reasons
cp %{SOURCE3} ${RPM_BUILD_ROOT}%{_libdir}/
chmod 0644 ${RPM_BUILD_ROOT}%{_libdir}/*.a

# Add the older v1.4.x shared members for compatibility with older apps
# (make sure they're set for LOADONLY with 'strip -e')
cp %{SOURCE4} libpng14.so.14
/usr/bin/strip -X32 -e libpng14.so.14
/usr/bin/ar -X32 -q ${RPM_BUILD_ROOT}%{_libdir}/libpng.a libpng14.so.14

cp %{SOURCE5} libpng14.so.14
/usr/bin/strip -X64 -e libpng14.so.14
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/libpng.a libpng14.so.14

# add compatibility symlinks
(
  cd ${RPM_BUILD_ROOT}%{_libdir}
  %{__ln_s} libpng.a libpng14.a
  %{__ln_s} libpng15.la libpng14.la
  %{__ln_s} libpng15.la libpng12.la
)

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc *.txt example.c README TODO CHANGES LICENSE 
%{_libdir}/*.a
%{_mandir}/man5/*
/usr/lib/*.a


%files devel
%defattr(-,root,system)
%{_bindir}/*
%{_includedir}/*
%{_libdir}/*.la
%{_libdir}/pkgconfig/*
%{_mandir}/man3/*
/usr/bin/*
/usr/include/*
/usr/lib/*.la


%changelog
* Fri Mar 29 2013 Michael Perzl <michael@perzl.org> - 1.5.15-1
- updated to version 1.5.15

* Tue Jan 29 2013 Michael Perzl <michael@perzl.org> - 1.5.14-1
- updated to version 1.5.14

* Fri Sep 28 2012 Michael Perzl <michael@perzl.org> - 1.5.13-1
- updated to version 1.5.13

* Mon Aug 13 2012 Michael Perzl <michael@perzl.org> - 1.5.12-2
- added two missing symbolic links for compatibility with older libpng versions

* Thu Jul 12 2012 Michael Perzl <michael@perzl.org> - 1.5.12-1
- updated to version 1.5.12

* Fri Jun 15 2012 Michael Perzl <michael@perzl.org> - 1.5.11-1
- updated to version 1.5.11

* Thu Mar 29 2012 Michael Perzl <michael@perzl.org> - 1.5.10-1
- updated to version 1.5.10

* Sun Feb 19 2012 Michael Perzl <michael@perzl.org> - 1.5.9-1
- updated to version 1.5.9

* Sat Feb 03 2012 Michael Perzl <michael@perzl.org> - 1.5.8-1
- updated to version 1.5.8

* Fri Dec 16 2011 Michael Perzl <michael@perzl.org> - 1.5.7-1
- updated to version 1.5.7

* Thu Nov 03 2011 Michael Perzl <michael@perzl.org> - 1.5.6-1
- updated to version 1.5.6

* Fri Sep 23 2011 Michael Perzl <michael@perzl.org> - 1.5.5-1
- updated to version 1.5.5

* Thu Jul 07 2011 Michael Perzl <michael@perzl.org> - 1.5.4-1
- updated to version 1.5.4

* Sat Apr 09 2011 Michael Perzl <michael@perzl.org> - 1.5.2-1
- updated to version 1.5.2

* Wed Jan 12 2011 Michael Perzl <michael@perzl.org> - 1.5.0-1
- updated to version 1.5.0

* Wed Jan 12 2011 Michael Perzl <michael@perzl.org> - 1.4.5-1
- updated to version 1.4.5

* Wed Jan 12 2011 Michael Perzl <michael@perzl.org> - 1.4.4-1
- updated to version 1.4.4

* Tue Jun 29 2010 Michael Perzl <michael@perzl.org> - 1.2.44-1
- updated to version 1.2.44

* Fri Feb 26 2010 Michael Perzl <michael@perzl.org> - 1.2.43-1
- updated to version 1.2.43

* Thu Feb 04 2010 Michael Perzl <michael@perzl.org> - 1.2.42-1
- updated to version 1.2.42

* Thu Dec 03 2009 Michael Perzl <michael@perzl.org> - 1.2.41-1
- updated to version 1.2.41

* Thu Sep 10 2009 Michael Perzl <michael@perzl.org> - 1.2.40-1
- updated to version 1.2.40

* Fri Aug 14 2009 Michael Perzl <michael@perzl.org> - 1.2.39-1
- updated to version 1.2.39

* Fri Jul 17 2009 Michael Perzl <michael@perzl.org> - 1.2.38-1
- updated to version 1.2.38

* Fri Jun 05 2009 Michael Perzl <michael@perzl.org> - 1.2.37-1
- updated to version 1.2.37

* Mon May 11 2009 Michael Perzl <michael@perzl.org> - 1.2.36-1
- updated to version 1.2.36

* Thu Feb 19 2009 Michael Perzl <michael@perzl.org> - 1.2.35-1
- updated to version 1.2.35

* Tue Dec 23 2008 Michael Perzl <michael@perzl.org> - 1.2.34-1
- updated to version 1.2.34

* Sat Nov 01 2008 Michael Perzl <michael@perzl.org> - 1.2.33-1
- updated to version 1.2.33

* Mon Sep 22 2008 Michael Perzl <michael@perzl.org> - 1.2.32-1
- updated to version 1.2.32

* Sat Aug 16 2008 Michael Perzl <michael@perzl.org> - 1.2.30-1
- updated to version 1.2.30

* Fri May 09 2008 Michael Perzl <michael@perzl.org> - 1.2.29-1
- updated to version 1.2.29

* Tue Apr 29 2008 Michael Perzl <michael@perzl.org> - 1.2.27-1
- updated to version 1.2.27

* Sun Mar 23 2008 Michael Perzl <michael@perzl.org> - 1.2.25-1
- first version for AIX V5.1 and higher
